Readiness

Struct Readiness 

pub struct Readiness { /* private fields */ }
Shared readiness state for the public health endpoint.

Startup keeps the service unready until its required components are available. Any critical component can make the service unready again.

Implementations

Source

impl Readiness

pub fn new(ready: bool) -> Self

pub fn mark_ready(&self)

pub fn mark_not_ready(&self)

pub fn is_ready(&self) -> bool