pub struct Readiness { /* private fields */ }Expand description
Shared readiness state for the public health endpoint.
Startup keeps the service unready until its required components are available. Any critical component can make the service unready again.
Implementations